@@ -31,6 +31,7 @@
 #include <QDialogButtonBox>
 #include <QLabel>
 #include <QLineEdit>
+#include <QPointer>
 #include <QPushButton>
 #include <QValidator>
 #include <QVBoxLayout>
@@ -74,18 +75,16 @@ KigInputDialog::KigInputDialog( const QString& caption, const QString& label,
     d( new KigInputDialogPrivate() )
 {
   QWidget *mainWidget = new QWidget( this );
-  QVBoxLayout *mainLayout = new QVBoxLayout;
+  QVBoxLayout *mainLayout = new QVBoxLayout( mainWidget );
   QDialogButtonBox *buttonBox = new QDialogButtonBox( QDialogButtonBox::Ok | QDialogButtonBox::Cancel );
-  QVBoxLayout* mainlay = new QVBoxLayout( mainWidget );
   
   setWindowTitle( caption );
   setLayout( mainLayout );
-  mainLayout->addWidget( mainWidget );
   d->okButton = buttonBox->button( QDialogButtonBox::Ok );
   d->okButton->setDefault( true );
   d->okButton->setShortcut( Qt::CTRL | Qt::Key_Return );
-  connect( buttonBox, SIGNAL(accepted()), this, SLOT(accept()) );
-  connect( buttonBox, SIGNAL(rejected()), this, SLOT(reject()) );
+  connect( buttonBox, &QDialogButtonBox::accepted, this, &KigInputDialog::accept );
+  connect( buttonBox, &QDialogButtonBox::rejected, this, &KigInputDialog::reject );
 
   d->m_coord1 = c1 ? Coordinate( *c1 ) : Coordinate::invalidCoord();
   d->m_coord2 = c2 ? Coordinate( *c2 ) : Coordinate::invalidCoord();
@@ -94,42 +93,36 @@ KigInputDialog::KigInputDialog( const QString& caption, const QString& label,
 
   bool ok = false;
 
-  mainlay->setMargin( 0 );
-  mainlay->activate();
-
   d->m_label = new QLabel( mainWidget );
   d->m_label->setTextFormat( Qt::RichText );
   d->m_label->setText( label );
-  mainlay->addWidget( d->m_label );
+  mainLayout->addWidget( d->m_label );
 
   d->m_lineEditFirst = new QLineEdit( mainWidget );
-//  d->m_lineEditFirst->setValidator( d->m_vtor );
+  d->m_lineEditFirst->setValidator( d->m_vtor );
   if ( d->m_coord1.valid() )
   {
     d->m_lineEditFirst->setText( d->m_doc->coordinateSystem().fromScreen( d->m_coord1, *d->m_doc ) );
     ok = true;
   }
-  mainlay->addWidget( d->m_lineEditFirst );
+  mainLayout->addWidget( d->m_lineEditFirst );
 
-  connect( d->m_lineEditFirst, SIGNAL(textChanged(QString)),
-           this, SLOT(slotCoordsChanged(QString)) );
+  connect( d->m_lineEditFirst, &QLineEdit::textChanged, this, &KigInputDialog::slotCoordsChanged );
 
   if ( d->m_coord2.valid() )
   {
     d->m_lineEditSecond = new QLineEdit( mainWidget );
-//    d->m_lineEditSecond->setValidator( d->m_vtor );
+    d->m_lineEditSecond->setValidator( d->m_vtor );
     d->m_lineEditSecond->setText( d->m_doc->coordinateSystem().fromScreen( d->m_coord2, *d->m_doc ) );
-    mainlay->addWidget( d->m_lineEditSecond );
+    mainLayout->addWidget( d->m_lineEditSecond );
 
-    connect( d->m_lineEditSecond, SIGNAL(textChanged(QString)),
-             this, SLOT(slotCoordsChanged(QString)) );
+    connect( d->m_lineEditSecond, &QLineEdit::textChanged, this, &KigInputDialog::slotCoordsChanged );
   }
 
   resize( minimumSizeHint() );
   d->m_lineEditFirst->setFocus();
   d->okButton->setEnabled( ok );
 
-  mainLayout->addWidget( mainWidget );
   mainLayout->addWidget( buttonBox );
 }
 
@@ -149,8 +142,8 @@ KigInputDialog::KigInputDialog( QWidget* parent, const Goniometry& g )
   okButton->setDefault( true );
   okButton->setShortcut( Qt::CTRL | Qt::Key_Return );
   d->okButton = okButton;
-  connect( buttonBox, SIGNAL(accepted()), this, SLOT(accept()) );
-  connect( buttonBox, SIGNAL(rejected()), this, SLOT(reject()) );
+  connect( buttonBox, &QDialogButtonBox::accepted, this, &QDialog::accept );
+  connect( buttonBox, &QDialogButtonBox::rejected, this, &QDialog::reject );
 
   d->m_gonio = g;
   d->m_gonioIsNum = true;
@@ -181,8 +174,8 @@ KigInputDialog::KigInputDialog( QWidget* parent, const Goniometry& g )
               "the left will be converted to the new selected unit." ) );
   horlay->addWidget( d->m_comboBox );
 
-  connect( d->m_lineEditFirst, SIGNAL(textChanged(QString)),
-           this, SLOT(slotGonioTextChanged(QString)) );
+  connect( d->m_lineEditFirst, &QLineEdit::textChanged,
+           this, &KigInputDialog::slotGonioTextChanged );
   connect( d->m_comboBox, SIGNAL(activated(int)),
            this, SLOT(slotGonioSystemChanged(int)) );
 
@@ -284,28 +277,32 @@ void KigInputDialog::getTwoCoordinates( const QString& caption, const QString& l
       QWidget* parent, bool* ok, const KigDocument& doc, Coordinate* cvalue,
       Coordinate* cvalue2 )
 {
-  KigInputDialog dlg( caption, label, parent, doc, cvalue, cvalue2 );
+  QPointer<KigInputDialog> dlg = new KigInputDialog( caption, label, parent, doc, cvalue, cvalue2 );
 
-  *ok = ( dlg.exec() == Accepted );
+  *ok = ( dlg->exec() == Accepted );
 
   if ( *ok )
   {
-    Coordinate a = dlg.coordinateFirst();
+    Coordinate a = dlg->coordinateFirst();
     *cvalue = a;
     if ( cvalue2 )
     {
-      Coordinate b = dlg.coordinateSecond();
+      Coordinate b = dlg->coordinateSecond();
       *cvalue2 = b;
     }
   }
-
+  delete dlg;
 }
 
 Goniometry KigInputDialog::getAngle( QWidget* parent, bool* ok, const Goniometry& g )
 {
-  KigInputDialog dlg( parent, g );
+  QPointer<KigInputDialog> dlg = new KigInputDialog( parent, g );
 
-  *ok = ( dlg.exec() == Accepted );
+  *ok = ( dlg->exec() == Accepted );
 
-  return dlg.goniometry();
+  Goniometry goniometry = dlg->goniometry();
+
+  delete dlg;
+
+  return goniometry;
 }
